IF OBJECT_ID('TR__Releases__ValidateSequence') IS NOT NULL DROP TRIGGER [TR__Releases__ValidateSequence]
GO

CREATE TRIGGER [TR__Releases__ValidateSequence]
       ON [Releases] FOR UPDATE, INSERT, DELETE
AS 
BEGIN

	IF EXISTS(
			SELECT *
			  FROM [Releases] R 
				   INNER JOIN (SELECT [Application_Id], 
                                      [Release_Number],
									  [Actual_Release_Sequence] = 
										   ROW_NUMBER() OVER (PARTITION BY [Application_Id]
										        ORDER BY [Application_Id], [Release_Sequence])
									  FROM [Releases]) R_ACTUAL
						   ON R.[Application_Id] = R_ACTUAL.[Application_Id]
                          AND R.[Release_Number] = R_ACTUAL.[Release_Number]
			 WHERE R.[Release_Sequence] <> R_ACTUAL.[Actual_Release_Sequence]
			   AND ( 
			         EXISTS ( SELECT * FROM inserted
			                   WHERE R.[Application_Id] = [Application_Id]
                                 AND R.[Release_Number] = [Release_Number] )
					 OR 
			         EXISTS ( SELECT * FROM deleted
			                   WHERE R.[Application_Id] = [Application_Id]
                                 AND R.[Release_Number] = [Release_Number] )
				   )
		) 
	BEGIN

		RAISERROR('An invalid Release_Sequence was provided for the Release.', 16, 1)
		ROLLBACK
	
	END
		
END
GO