EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Environments_CreateOrUpdateEnvironment',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Environment_Id',
    /* Description_Text        */ 'Creates a new environment or updates an existing one'
GO


IF OBJECT_ID('[Environments_CreateOrUpdateEnvironment]') IS NOT NULL DROP PROCEDURE [Environments_CreateOrUpdateEnvironment]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Environments_CreateOrUpdateEnvironment]
(
	@Environment_Name VARCHAR(50) = NULL,
    @ServerIds_Csv VARCHAR(MAX) = NULL,
    @Parent_Environment_Id INT = NULL,
    @Display_Sequence INT = NULL, 
	@Active_Indicator YNINDICATOR = NULL,
    @Environment_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF (@Environment_Id IS NULL) BEGIN
		 SELECT @Display_Sequence = COALESCE(MAX([Display_Sequence] ),0)+1
		   FROM [Environments]
		BEGIN
			INSERT INTO [Environments] 
			(
				[Environment_Name],
				[Display_Sequence],
				[CreatedBy_User_Name],
				[CreatedOn_Date],
				[ModifiedBy_User_Name],
				[ModifiedOn_Date],
                [Parent_Environment_Id],
				[Active_Indicator]
			)
			VALUES 
			(
				@Environment_Name,
				@Display_Sequence,
				dbo.Session_GetUserName(),
				GETUTCDATE(),
				dbo.Session_GetUserName(),
				GETUTCDATE(),
                @Parent_Environment_Id,
				ISNULL(@Active_Indicator, 'Y')
			)
			SET @Environment_Id = SCOPE_IDENTITY()

			EXEC [Events_RaiseEvent] 'ENVNEW', NULL, @Environment_Id
		END

	END ELSE
		BEGIN
			UPDATE [Environments]
			   SET [Environment_Name] = COALESCE(@Environment_Name, [Environment_Name]),
				   [ModifiedBy_User_Name] = dbo.Session_GetUserName(),
				   [ModifiedOn_Date] = GETUTCDATE(),
                   [Display_Sequence] = COALESCE(@Display_Sequence, [Display_Sequence]),
                   [Parent_Environment_Id] = @Parent_Environment_Id,
				   [Active_Indicator] = ISNULL(@Active_Indicator, 'Y')
				   
			 WHERE [Environment_Id] = @Environment_Id

			EXEC [Events_RaiseEvent] 'ENVMOD', NULL, @Environment_Id
		END


    IF @ServerIds_Csv IS NOT NULL
    BEGIN
     DELETE [EnvironmentServers] WHERE [Environment_Id] = @Environment_Id

        INSERT [EnvironmentServers] ([Environment_Id], [Server_Id])
        SELECT @Environment_Id, [Value_Text] 
          FROM [dbo].[CsvToTable] (@ServerIds_Csv, ',')
    END


	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Environments_CreateOrUpdateEnvironment] TO [BuildMasterUser_Role]
