EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Variables_CreateOrUpdateBuildVariable',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a new build variable or sets an existing build variable''s value.'
GO

IF OBJECT_ID('[Variables_CreateOrUpdatePackageVariable]') IS NOT NULL DROP PROCEDURE [Variables_CreateOrUpdatePackageVariable]
GO
IF OBJECT_ID('[Variables_CreateOrUpdateBuildVariable]') IS NOT NULL DROP PROCEDURE [Variables_CreateOrUpdateBuildVariable]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Variables_CreateOrUpdateBuildVariable]
(
    @Build_Id INT,
	@Variable_Name VARCHAR(50),
	@ValueType_Code CHAR(1),
	@Variable_Value VARBINARY(MAX),
    @Sensitive_Indicator YNINDICATOR,
    @EvaluateVariables_Indicator YNINDICATOR
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT *
	            FROM [BuildVariables]
			   WHERE [Build_Id] = @Build_Id
                 AND [Variable_Name] = @Variable_Name)
	BEGIN

		UPDATE [BuildVariables]
		   SET [ValueType_Code] = @ValueType_Code,
		       [Variable_Value] = @Variable_Value,
               [Sensitive_Indicator] = @Sensitive_Indicator,
               [EvaluateVariables_Indicator] = @EvaluateVariables_Indicator
		 WHERE [Build_Id] = @Build_Id
           AND [Variable_Name] = @Variable_Name

	END
	ELSE
	BEGIN

		INSERT INTO [BuildVariables]
		(
			[Build_Id],
            [Variable_Name],
            [ValueType_Code],
			[Variable_Value],
            [Sensitive_Indicator],
            [EvaluateVariables_Indicator]
		)
		VALUES
		(
            @Build_Id,
            @Variable_Name,
            @ValueType_Code,
            @Variable_Value,
            @Sensitive_Indicator,
            @EvaluateVariables_Indicator
		)

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Variables_CreateOrUpdateBuildVariable] TO [BuildMasterUser_Role]
